###########################################################################
# FLEMM-v3.1 -- French Lemmatizer : Lemmatisation du franais  partir de # 
# corpus tiquets - Version 3.1					  #
# Copyright (C) 2004 (NAMER Fiammetta)					  #
###########################################################################
#
# $Id$
#

package Flemm;

use strict;

use Flemm::Brill;
use Flemm::TreeTagger;

#
# Mthodes publiques
#

# Constructeur
# Renvoie un objet de type Flemm::Brill ou Flemm::TreeTagger
# Lance une exception si le type de Tagger n'est pas prcis
sub new {
    my $type=shift;
    my (%params)=@_;

    my $self=undef;
    my $tagger=undef;
    my %p;

    if (exists $params{Logname}) {
	$p{Logname}=$params{Logname};
    }
    
    if (exists $params{Format}) {
	$p{Format}=$params{Format};
    }
    
    if (exists $params{Tagger}) {
	$tagger=$params{Tagger};
	if ($tagger =~ /brill/i) {
	    $self=new Flemm::Brill(%p);
	}
	elsif ($tagger =~ /(treetagger|tt)/i) {
	    $self=new Flemm::TreeTagger(%p);
	}
	else {
	    die "Flemm::new(): $tagger n'est pas un tiqueteur reconnu\n";
	}
    }
    else {
	$self=new Flemm::TreeTagger(%p);
    }
    
    return $self;
}

1;

__END__

=head1 NAME

Flemm - Lemmatisation du franais  partir de corpus tiquets

=head1 SYNOPSIS

=head2 Exemple1 (tiquetage Brill, sortie linaire)

  use Flemm;
  use Flemm::Result;

  my $lemm=new Flemm(
                'Tagger' => 'Brill',
                'Logname' => '/tmp/log_errors'
               );
 

  while (<>) {
    chomp;
    my $res=$lemm->lemmatize($_);
    print $res->getResult;
}

echo 'fabriquera/VCJ:sg'|perl exemple1.pl > result_brill.txt
 
=head2 Exemple2 (tiquetage Treetagger, sortie xml)

  use Flemm;
  use Flemm::Result;
  my $lemm=new Flemm(
                'Logname' => '/tmp/log_errors'
               );
 
 print "<?xml version='1.0' encoding='ISO-8859-1'?>\n\n";
 print "<FlemmResults>\n";
  while (<>) {
    chomp;
    my $res=$lemm->lemmatize($_);
    print $res->asXML;
 }
 print "</FlemmResults>\n";


echo 'gnralisent	VER:pres	gnraliser'|perl exemple2.pl > result_tt.xml
 

=head1 DESCRIPTION

Flemm effectue l'analyse morpho-flexionnelle d'une forme flchie tiquete.
Le rsultat inclut le lemme (forme non flchie conventionnellement associe
 la forme analyse) ainsi que l'ensemble des traits flexionnels calculables
hors contexte. 
La dfinition et la valeur de ces traits sont conformes aux normes dfinies dans
Multext (http://www.lpl.univ-aix.fr/projects/multext/). 
Le rsultat peut tre affich au format xml. 
L'affichage du rsultat ncessite l'usage du module Flemm::Result;

Principales caractristiques:

=over 3

=item * Etiquetage de l'input : Brill entran pour le franais 
(http://www.atilf.fr) ou 
TreeTagger (http://www.ims.uni-stuttgart.de/projekte/corplex/TreeTagger/DecisionTreeTagger.html)

=item * bas sur rgles + liste d'exceptions

=item * contrle et ventuellement correction de l'tiquetage d'origine, en fonction de 
la terminaison de la forme flchie

=back

=cut

=head1 METHODES

=over 3

=item new(%params)

La mthode new permet de crer un objet de type Flemm::Brill ou de type Flemm::TreeTagger, 
en fonction de la valeur du paramtre tagger.

Les paramtres possibles, passs  new via un hashage sont les suivants:

=over 4

=item * Tagger = (Brill|TreeTagger) (par dfaut : TreeTagger)

=item * Logname = prefixe des fichiers log

=item * Format = (normal|xml), (par dfaut : normal)

=back

La mthode de lemmatisation est appele par l'objet cre, selon son 
type (Flemm::Brill ou Flemm::Treetagger) dans le module appropri 


=item Flemm::TreeTagger::lemmatize($input_string) /

=item Flemm::Brill::lemmatize($input_string)

Quel que soit son type, la mthode lemmatize se charge de la 
lemmatisation  proprement parler de $input_string, c'est  dire :

=over 4

=item * identifie la forme flchie et la catgorie

=item * valide la catgorie et la corrige si ncessaire

=item * appelle les fonctions de  calcul du lemme et des traits morpho-flexionnels

=item * produit un rsultat de type Flemm::Result;

=item * lui applique les mthodes qui identifie les diffrentes parties de l'analyse rsultante de la lemmatisation

=back

=cut

=head1 SEE ALSO

Flemm::TreeTagger, Flemm::Brill, Flemm::Result


=cut
